/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: PoolItemInfo.java 4961 2009-05-17 11:44:57Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.pool.impl.enhanced.impl.keepbusy;

import java.io.CharArrayWriter;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 *
 * @author Gael Lalire
 */
public class PoolItemInfo {

    private static final Log LOG = LogFactory.getLog(PoolItemInfo.class);

    private int busyCount;

    private boolean removed;

    private List<Throwable> throwableList;

    public PoolItemInfo() {
        this.busyCount = 1;
        this.removed = false;
        throwableList = new ArrayList<Throwable>();
    }

    /**
     * @return the busyCount
     */
    public int getBusyCount() {
        return busyCount;
    }

    /**
     * @param busyCount the busyCount to set
     */
    public void setBusyCount(final int busyCount) {
        this.busyCount = busyCount;
    }

    /**
     * @return the removed
     */
    public boolean isRemoved() {
        return removed;
    }

    /**
     * @param removed the removed to set
     */
    public void setRemoved(final boolean removed) {
        this.removed = removed;
    }

    public void addStackTraceElements(final Throwable throwable) {
        throwableList.add(throwable);
    }

    @Override
    protected void finalize() throws Throwable {
        int busyCount = getBusyCount();
        if (busyCount != 0) {
            if (LOG.isWarnEnabled()) {
                CharArrayWriter charArrayWriter = new CharArrayWriter();
                PrintWriter printWriter = new PrintWriter(charArrayWriter);
                for (Throwable throwable : throwableList) {
                    throwable.printStackTrace(printWriter);
                    printWriter.append("\n");
                }
                LOG.warn("A poolItem was GC while {0} user didn''t send back their instance to pool.\nStackTraces :\n{1}",
                        busyCount, charArrayWriter);
            }
        }
    }

}
